==> python-data-converter-0.0.6.tar.gz: python-data-converter-0.0.6/LICENSE.md <==
# End User License Agreement  

Copyright (c) 2019 - present [AppSeed](http://appseed.us/)

<br />

## General Information

This document explains the usage of this **open-source** product developed by **[AppSeed](http://appseed.us/)**. 

> The Terms:

- `Solo-Developer`: code digital products as freelencer (without being incorporated in a company)
- `StartUp` - young company founded 12mo (or less) in the past
- `Small Company` - maximum 5 developers, active for more than 1year 
- `Company` - More than 5 developers and less than 50
- `Corporate` - More than 50 developers 
- `NGO` - [Non Governmental Organization](https://en.wikipedia.org/wiki/Non-governmental_organization)

<br />

### Free Usage 

| **Target Entities** - Who can benefit | --- |
| ---------------------------------- | --- |
| Solo-Developers | **YES** |
| [NGOs](https://en.wikipedia.org/wiki/Non-governmental_organization) | **YES** |
| --- | --- |
| **End Products** | --- |
| Personal Use | **YES** |
| eLearning Activities | **YES** |
| Projects (non-paying users) | **YES** |
| End-Product usage for [NGOs](https://en.wikipedia.org/wiki/Non-governmental_organization) | **YES** |
| --- | --- |
| **Support** | --- |
| Github (issues tracker) | **YES** |
| Email *support @ appseed.us* | **YES** |
| --- | --- |
| **Forbidden Usage** | --- |
| `End-products` for sale - paying, non-paying users | **NO** (license required) |
| Used by `StartUPs` | **NO** (license required) |
| Used by `Companies` | **NO** (license required) |
| Used in `Corporates`, 50+ developers | **NO** (license required) |
| `End-Product` for `Government` - All Countries | **NO** (license required) |
| `End-Product sale` to users/companies | **NO** (license required) |

<br />

### Lifetime License

> `One-time Payment` via GUMROAD - [$299](https://appseed.gumroad.com/l/devtool-python-converter) (payment link)

The license covers: 

- `Usage in commercial` projects
- `Usage in eLearning` activities
- `Unlimited copies`
- `Premium Support` via Email / Discord 

> `IMPORTANT`: The **end-product that used the tool should NOT compete with AppSeed**.

<br />

---
For more information regarding licensing, please contact the AppSeed Service < *support@appseed.us* >

==> python-data-converter-0.0.7.tar.gz: python-data-converter-0.0.7/LICENSE.md <==
# End User License Agreement  

Copyright (c) 2019 - present [AppSeed](http://appseed.us/)

<br />

## General Information

This document explains the usage of this **open-source** product developed by **[AppSeed](http://appseed.us/)**. 

> The Terms:

- `Solo-Developer`: code digital products as freelencer (without being incorporated in a company)
- `StartUp` - young company founded 12mo (or less) in the past
- `Small Company` - maximum 5 developers, active for more than 1year 
- `Company` - More than 5 developers and less than 50
- `Corporate` - More than 50 developers 
- `NGO` - [Non Governmental Organization](https://en.wikipedia.org/wiki/Non-governmental_organization)

<br />

### Free Usage 

| **Target Entities** - Who can benefit | --- |
| ---------------------------------- | --- |
| Solo-Developers | **YES** |
| [NGOs](https://en.wikipedia.org/wiki/Non-governmental_organization) | **YES** |
| --- | --- |
| **End Products** | --- |
| Personal Use (hobby projects) | **YES** |
| eLearning Activities | **YES** |
| End-Product usage for [NGOs](https://en.wikipedia.org/wiki/Non-governmental_organization) | **YES** |
| --- | --- |
| **Support** | --- |
| Github (issues tracker) | **YES** |
| Email *support @ appseed.us* | **YES** |
| --- | --- |
| **Forbidden Usage** (without a license) | --- |
| `End-products` for sale - paying, non-paying users | **NO** (license required) |
| Used by `StartUPs` | **NO** (license required) |
| Used by `Companies` | **NO** (license required) |
| Used in `Corporates`, 50+ developers | **NO** (license required) |
| `End-Product` for `Government` - All Countries | **NO** (license required) |
| `End-Product sale` to users/companies | **NO** (license required) |

<br />

### Lifetime License

> `One-time Payment` via GUMROAD - [$299](https://appseed.gumroad.com/l/devtool-python-converter) (payment link)

The license covers: 

- `Usage in commercial` projects
- `Usage in eLearning` activities
- `Unlimited projects` (hobby, commercial)
- `Premium` [Support](https://appseed.us/support/) via Email / `Discord`

> `IMPORTANT`: The **end-product that used the tool should NOT compete with AppSeed**.

<br />

---
For more information regarding licensing, please contact the AppSeed Service < *support@appseed.us* >
